@@ -19,7 +19,7 @@ setattr = object.__setattr__
 
 # %% Functions
 
-def must_compile(*args, **kwargs):
+def must_compile(*args, **kwargs): # pragma: no cover
     raise TypeError("method valid only for compiled chemicals; "
                     "run <Chemicals>.compile() to compile")
 
@@ -46,13 +46,15 @@ class Chemicals:
            * PubChem CID, prefixed by 'PubChem='
            * SMILES (prefix with 'SMILES=' to ensure smiles parsing)
            * CAS number
+    cache : bool, optional
+        Wheather or not to use cached chemicals.
     
     Examples
     --------
     Create a Chemicals object from chemical identifiers:
     
     >>> from thermosteam import Chemicals
-    >>> chemicals = Chemicals(['Water', 'Ethanol'])
+    >>> chemicals = Chemicals(['Water', 'Ethanol'], cache=True)
     >>> chemicals
     Chemicals([Water, Ethanol])
     
@@ -61,15 +63,67 @@ class Chemicals:
     >>> chemicals.Water, chemicals.Ethanol
     (Chemical('Water'), Chemical('Ethanol'))
     
+    Chemicals can also be accessed as items:
+    
+    >>> chemicals = Chemicals(['Water', 'Ethanol', 'Propane'], cache=True)
+    >>> chemicals['Ethanol']
+    Chemical('Ethanol')
+    >>> chemicals['Propane', 'Water']
+    [Chemical('Propane'), Chemical('Water')]
+    
+    A Chemicals object can be extended with more chemicals:
         
+    >>> from thermosteam import Chemical
+    >>> Methanol = Chemical('Methanol')
+    >>> chemicals.append(Methanol)
+    >>> chemicals
+    Chemicals([Water, Ethanol, Propane, Methanol])
+    >>> new_chemicals = Chemicals(['Hexane', 'Octanol'], cache=True)
+    >>> chemicals.extend(new_chemicals)
+    >>> chemicals
+    Chemicals([Water, Ethanol, Propane, Methanol, Hexane, Octanol])
+    
+    Chemical objects cannot be repeated:
+    
+    >>> chemicals.append(chemicals.Water)
+    Traceback (most recent call last):
+    ValueError: Water already defined in chemicals
+    >>> chemicals.extend(chemicals['Ethanol', 'Octanol'])
+    Traceback (most recent call last):
+    ValueError: Ethanol already defined in chemicals
+    
+    A Chemicals object can only contain Chemical objects:
+        
+    >>> chemicals.append(10)
+    Traceback (most recent call last):
+    TypeError: only 'Chemical' objects can be appended, not 'int'
+    
+    You can check whether a Chemicals object contains a given chemical:
+        
+    >>> 'Water' in chemicals
+    True
+    >>> chemicals.Water in chemicals
+    True
+    >>> 'Butane' in chemicals
+    False
+    
+    An attempt to access a non-existent chemical raises an UndefinedChemical error:
+    
+    >>> chemicals['Butane']
+    Traceback (most recent call last):
+    UndefinedChemical: 'Butane'
+    
     """
-    def __init__(self, chemicals):
+    def __new__(cls, chemicals, cache=False):
+        self = super().__new__(cls)
         isa = isinstance
+        setfield = setattr
         for chem in chemicals:
             if isa(chem, Chemical):
-                setattr(self, chem.ID, chem)
+                setfield(self, chem.ID, chem)
             else:
-                setattr(self, chem, Chemical(chem))
+                setfield(self, chem, Chemical(chem, cache=cache))
+        return self
     
     def __getnewargs__(self):
         return (tuple(self),)
@@ -88,13 +142,6 @@ class Chemicals:
         ----------
         key : Iterable[str] or str
               Chemical identifiers.
-              
-        Examples
-        --------
-        
-        >>> chemicals = Chemicals(['Water', 'Ethanol', 'Propane'])
-        >>> chemicals['Propane', 'Water']
-        [Chemical('Propane'), Chemical('Water')]
         
         """
         dct = self.__dict__
@@ -108,10 +155,12 @@ class Chemicals:
     
     def append(self, chemical):
         """Append a Chemical."""
-        assert isinstance(chemical, Chemical), ("only 'Chemical' objects are allowed, "
-                                               f"not '{type(chemical).__name__}'")
+        if not isinstance(chemical, Chemical):
+            raise TypeError("only 'Chemical' objects can be appended, "
+                           f"not '{type(chemical).__name__}'")
         ID = chemical.ID
-        assert ID not in self.__dict__, f"{ID} already defined in chemicals"
+        if ID in self.__dict__:
+            raise ValueError(f"{ID} already defined in chemicals")
         setattr(self, ID, chemical)
     
     def extend(self, chemicals):
@@ -119,10 +168,7 @@ class Chemicals:
         if isinstance(chemicals, Chemicals):
             self.__dict__.update(chemicals.__dict__)
         else:
-            for chemical in chemicals:
-                assert isinstance(chemical, Chemical), ("only 'Chemical' objects are allowed, "
-                                                        f"not '{type(chemical).__name__}'")
-                setattr(self, chemical.ID, chemical)
+            for chemical in chemicals: self.append(chemical)
     
     def subgroup(self, IDs):
         """
@@ -169,7 +215,7 @@ class Chemicals:
             return chemical in self.__dict__
         elif isinstance(chemical, Chemical):
             return chemical in self.__dict__.values()
-        else:
+        else: # pragma: no cover
             return False
     
     def __iter__(self):
@@ -194,6 +240,8 @@ class CompiledChemicals(Chemicals):
               * PubChem CID, prefixed by 'PubChem='
               * SMILES (prefix with 'SMILES=' to ensure smiles parsing)
               * CAS number
+    cache : optional
+        Whether or not to use cached chemicals.
         
     Attributes
     ----------
@@ -225,7 +273,7 @@ class CompiledChemicals(Chemicals):
     Create a CompiledChemicals object from chemical identifiers
     
     >>> from thermosteam import CompiledChemicals, Chemical
-    >>> chemicals = CompiledChemicals(['Water', 'Ethanol'])
+    >>> chemicals = CompiledChemicals(['Water', 'Ethanol'], cache=True)
     >>> chemicals
     CompiledChemicals([Water, Ethanol])
     
@@ -236,27 +284,37 @@ class CompiledChemicals(Chemicals):
     
     Note that because they are compiled, the append and extend methods do not work:
         
-    >>> # Propane = Chemical('Propane')
-    >>> # chemicals.append(Propane)
-    >>> # TypeError: 'CompiledChemicals' object is read-only
+    >>> Propane = Chemical('Propane', cache=True)
+    >>> chemicals.append(Propane)
+    Traceback (most recent call last):
+    TypeError: 'CompiledChemicals' object is read-only
+    
+    You can check whether a Chemicals object contains a given chemical:
         
+    >>> 'Water' in chemicals
+    True
+    >>> chemicals.Water in chemicals
+    True
+    >>> 'Butane' in chemicals
+    False
     
     """  
     _cache = {}
     
-    def __new__(cls, chemicals):
+    def __new__(cls, chemicals, cache=None):
         isa = isinstance
-        chemicals = tuple([chem if isa(chem, Chemical) else Chemical(chem)
+        chemicals = tuple([chem if isa(chem, Chemical) else Chemical(chem, cache)
                            for chem in chemicals])        
         cache = cls._cache
         if chemicals in cache:
             self = cache[chemicals]
         else:
-            self = super().__new__(cls)
+            self = object.__new__(cls)
             setfield = setattr
             for chem in chemicals:
                 setfield(self, chem.ID, chem)
             self._compile()
+            cache[chemicals] = self
         return self
     
     def __dir__(self):
@@ -288,7 +346,20 @@ class CompiledChemicals(Chemicals):
         dct['HHV'] = chemical_data_array([i.HHV for i in chemicals])
 
     def get_combustion_reactions(self):
-        """Return a ParallelReactions object with all defined combustion reactions."""
+        """
+        Return a ParallelReactions object with all defined combustion reactions.
+        
+        Examples
+        --------
+        >>> chemicals = CompiledChemicals(['H2O', 'Methanol', 'Ethanol', 'CO2', 'O2'], cache=True)
+        >>> rxns = chemicals.get_combustion_reactions()
+        >>> rxns.show()
+        ParallelReaction (by mol):
+        index  stoichiometry                     reactant    X[%]
+        [0]    Methanol + 1.5 O2 -> 2 H2O + CO2  Methanol  100.00
+        [1]    Ethanol + 3 O2 -> 3 H2O + 2 CO2   Ethanol   100.00
+        
+        """
         reactions = [i.get_combustion_reaction(self) for i in self]
         return tmo.reaction.ParallelReaction([i for i in reactions if i is not None])
 
@@ -362,11 +433,133 @@ class CompiledChemicals(Chemicals):
         Each column is a chemical and each row an element.
         Rows are ordered by atomic number.
         
+        Examples
+        --------
+        >>> chemicals = CompiledChemicals(['Water', 'Ethanol', 'Propane'], cache=True)
+        >>> chemicals.formula_array
+        array([[2., 6., 8.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 2., 3.],
+               [0., 0., 0.],
+               [1., 1., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.],
+               [0., 0., 0.]])
         """
         try: return self._formula_array
         except: pass
         self.__dict__['_formula_array'] = formula_array = np.zeros((118, self.size))
-        atoms_to_array = tmo.properties.elements.atoms_to_array
+        atoms_to_array = tmo.chemicals.elements.atoms_to_array
         for i, chemical in enumerate(self):
             formula_array[:, i] = atoms_to_array(chemical.atoms)
         formula_array.setflags(0)
@@ -383,8 +576,7 @@ class CompiledChemicals(Chemicals):
               
         Examples
         --------
-        
-        >>> chemicals = CompiledChemicals(['Water', 'Ethanol', 'Propane'])
+        >>> chemicals = CompiledChemicals(['Water', 'Ethanol', 'Propane'], cache=True)
         >>> chemicals.subgroup(['Propane', 'Water'])
         CompiledChemicals([Propane, Water])
         
@@ -412,7 +604,7 @@ class CompiledChemicals(Chemicals):
         Get all synonyms of water:
         
         >>> from thermosteam import CompiledChemicals
-        >>> chemicals = CompiledChemicals(['Water'])
+        >>> chemicals = CompiledChemicals(['Water'], cache=True)
         >>> chemicals.get_synonyms('Water')
         ['7732-18-5', 'Water']
         
@@ -437,11 +629,16 @@ class CompiledChemicals(Chemicals):
         Set new synonym for water:
         
         >>> from thermosteam import CompiledChemicals
-        >>> chemicals = CompiledChemicals(['Water'])
+        >>> chemicals = CompiledChemicals(['Water', 'Ethanol'], cache=True)
         >>> chemicals.set_synonym('Water', 'H2O')
         >>> chemicals.H2O is chemicals.Water
         True
         
+        Note that you cannot use one synonym for two chemicals:
+        
+        >>> chemicals.set_synonym('Ethanol', 'H2O')
+        Traceback (most recent call last):
+        ValueError: synonym 'H2O' already in use by Chemical('Water')
         
         """
         chemical = getattr(self, ID)
@@ -459,7 +656,7 @@ class CompiledChemicals(Chemicals):
         Examples
         --------
         >>> from thermosteam import CompiledChemicals
-        >>> chemicals = CompiledChemicals(['Water', 'Ethanol'])
+        >>> chemicals = CompiledChemicals(['Water', 'Ethanol'], cache=True)
         >>> chemicals.zeros()
         array([0., 0.])
         
@@ -473,7 +670,7 @@ class CompiledChemicals(Chemicals):
         Examples
         --------
         >>> from thermosteam import CompiledChemicals
-        >>> chemicals = CompiledChemicals(['Water', 'Ethanol'])
+        >>> chemicals = CompiledChemicals(['Water', 'Ethanol'], cache=True)
         >>> chemicals.ones()
         array([1., 1.])
         
@@ -492,7 +689,7 @@ class CompiledChemicals(Chemicals):
         Examples
         --------
         >>> from thermosteam import CompiledChemicals
-        >>> chemicals = CompiledChemicals(['Water', 'Ethanol'])
+        >>> chemicals = CompiledChemicals(['Water', 'Ethanol'], cache=True)
         >>> chemicals.kwarray(dict(Water=2))
         array([2., 0.])
         
@@ -513,7 +710,7 @@ class CompiledChemicals(Chemicals):
         Examples
         --------
         >>> from thermosteam import CompiledChemicals
-        >>> chemicals = CompiledChemicals(['Water', 'Ethanol'])
+        >>> chemicals = CompiledChemicals(['Water', 'Ethanol'], cache=True)
         >>> chemicals.array(['Water'], [2])
         array([2., 0.])
         
@@ -538,7 +735,7 @@ class CompiledChemicals(Chemicals):
         Create a chemical indexer from chemical IDs and data:
         
         >>> from thermosteam import CompiledChemicals
-        >>> chemicals = CompiledChemicals(['Water', 'Methanol', 'Ethanol'])
+        >>> chemicals = CompiledChemicals(['Water', 'Methanol', 'Ethanol'], cache=True)
         >>> chemical_indexer = chemicals.iarray(['Water', 'Ethanol'], [2., 1.])
         >>> chemical_indexer.show()
         ChemicalIndexer:
@@ -570,7 +767,7 @@ class CompiledChemicals(Chemicals):
         Create a chemical indexer from chemical IDs and data:
         
         >>> from thermosteam import CompiledChemicals
-        >>> chemicals = CompiledChemicals(['Water', 'Methanol', 'Ethanol'])
+        >>> chemicals = CompiledChemicals(['Water', 'Methanol', 'Ethanol'], cache=True)
         >>> chemical_indexer = chemicals.ikwarray(dict(Water=2., Ethanol=1.))
         >>> chemical_indexer.show()
         ChemicalIndexer:
@@ -606,7 +803,7 @@ class CompiledChemicals(Chemicals):
         From a dictionary:
         
         >>> from thermosteam import CompiledChemicals
-        >>> chemicals = CompiledChemicals(['Water', 'Methanol', 'Ethanol'])
+        >>> chemicals = CompiledChemicals(['Water', 'Methanol', 'Ethanol'], cache=True)
         >>> chemical_indexer = chemicals.isplit(dict(Water=0.5, Ethanol=1.))
         >>> chemical_indexer.show()
         ChemicalIndexer:
@@ -615,8 +812,6 @@ class CompiledChemicals(Chemicals):
         
         From iterable given the order:
         
-        >>> from thermosteam import CompiledChemicals
-        >>> chemicals = CompiledChemicals(['Water', 'Methanol', 'Ethanol'])
         >>> chemical_indexer = chemicals.isplit([0.5, 1], ['Water', 'Ethanol'])
         >>> chemical_indexer.show()
         ChemicalIndexer:
@@ -625,8 +820,6 @@ class CompiledChemicals(Chemicals):
            
         From a fraction:
         
-        >>> from thermosteam import CompiledChemicals
-        >>> chemicals = CompiledChemicals(['Water', 'Methanol', 'Ethanol'])
         >>> chemical_indexer = chemicals.isplit(0.75)
         >>> chemical_indexer.show()
         ChemicalIndexer:
@@ -634,6 +827,14 @@ class CompiledChemicals(Chemicals):
          Methanol  0.75
          Ethanol   0.75
             
+        From an iterable (assuming same order as the Chemicals object):
+        
+        >>> chemical_indexer = chemicals.isplit([0.5, 0, 1])
+        >>> chemical_indexer.show()
+        ChemicalIndexer:
+         Water    0.5
+         Ethanol  1
+            
         """
         if isinstance(split, dict):
             assert not order, "cannot pass 'order' key word argument when split is a dictionary"
@@ -725,25 +926,39 @@ class CompiledChemicals(Chemicals):
 
         Examples
         --------
-        Get multiple indices:
+        Get multiple indices with a tuple of IDs:
         
         >>> from thermosteam import CompiledChemicals
-        >>> chemicals = CompiledChemicals(['Water', 'Ethanol'])
+        >>> chemicals = CompiledChemicals(['Water', 'Ethanol'], cache=True)
         >>> IDs = ('Water', 'Ethanol')
         >>> chemicals.get_index(IDs)
         [0, 1]
         
-        Get a single index:
+        Get a single index with a string:
         
         >>> chemicals.get_index('Ethanol')
         1
+        
+        An Ellipsis returns a slice:
+        
+        >>> chemicals.get_index(...)
+        slice(None, None, None)
+
+        Anything else returns an error:
+        
+        >>> chemicals.get_index(['Water', 'Ethanol'])
+        Traceback (most recent call last):
+        TypeError: only strings, tuples, and ellipsis are valid index keys
 
         """
         cache = self._index_cache
         try: 
             index = cache[IDs]
         except KeyError: 
-            if len(cache) > 1000: cache.clear()
+            if len(cache) > 1000: # pragma: no cover
+                for i in cache:
+                    del cache[i]
+                    break
             cache[IDs] = index = self._get_index(IDs)
         except TypeError:
             raise TypeError("only strings, tuples, and ellipsis are valid index keys")
@@ -755,8 +970,8 @@ class CompiledChemicals(Chemicals):
         elif isinstance(IDs, tuple):
             return self.indices(IDs)
         elif IDs is ...:
-            return IDs
-        else:
+            return slice(None)
+        else: # pragma: no cover
             raise TypeError("only strings, tuples, and ellipsis are valid index keys")    
     
     def __len__(self):
@@ -767,7 +982,7 @@ class CompiledChemicals(Chemicals):
             return chemical in self.__dict__
         elif isinstance(chemical, Chemical):
             return chemical in self.tuple
-        else:
+        else: # pragma: no cover
             return False
     
     def __iter__(self):
@@ -784,10 +999,10 @@ class CompiledChemicals(Chemicals):
         >>> chemicals = CompiledChemicals(['Water', 'Methanol', 'Ethanol'])
         >>> data = chemicals.kwarray(dict(Water=2., Ethanol=1.))
         >>> chemicals.get_vle_indices(data!=0)
-        array([0, 2], dtype=int64)
+        [0, 2]
         
         """
-        return np.where(self._has_vle & nonzeros)[0]
+        return [i for i, j in enumerate(self._has_vle & nonzeros) if j]
     
     def get_lle_indices(self, nonzeros):
         """
@@ -800,10 +1015,10 @@ class CompiledChemicals(Chemicals):
         >>> chemicals = CompiledChemicals(['Water', 'Methanol', 'Ethanol'])
         >>> data = chemicals.kwarray(dict(Water=2., Ethanol=1.))
         >>> chemicals.get_lle_indices(data!=0)
-        array([0, 2], dtype=int64)
+        [0, 2]
         
         """
-        return np.where(self._has_lle & nonzeros)[0]
+        return [i for i, j in enumerate(self._has_lle & nonzeros) if j]
     
     def __repr__(self):
         return f"{type(self).__name__}([{', '.join(self.IDs)}])"
\ No newline at end of file
