@@ -14,7 +14,7 @@ from . import equilibrium as eq
 from . import functional as fn
 from . import units_of_measure as thermo_units
 from .exceptions import DimensionError
-from chemicals.elements import array_to_atoms, atomic_index
+from chemicals.elements import array_to_atoms, symbol_to_index
 from . import utils
 
 __all__ = ('Stream', )
@@ -66,7 +66,7 @@ class Stream:
     Before creating a stream, first set the chemicals:
         
     >>> import thermosteam as tmo
-    >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
+    >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
     
     Create a stream, defining the thermodynamic condition and flow rates:
         
@@ -242,7 +242,18 @@ class Stream:
         self._price = float(price)
     
     def isempty(self):
-        """Return whether or not stream is empty."""
+        """
+        Return whether or not stream is empty.
+        
+        Examples
+        --------
+        >>> import thermosteam as tmo
+        >>> tmo.settings.set_thermo(['Water'], cache=True)
+        >>> stream = tmo.Stream()
+        >>> stream.isempty()
+        True
+        
+        """
         return (self._imol._data == 0.).all()
 
     @property
@@ -324,19 +335,35 @@ class Stream:
 
     def get_atomic_flow(self, symbol):
         """
-        Return flow rate of atom in kmol / hr.
+        Return flow rate of atom in kmol / hr given the atomic symbol.
+        
+        Examples
+        --------
+        >>> import thermosteam as tmo
+        >>> tmo.settings.set_thermo(['Water'], cache=True)
+        >>> stream = tmo.Stream(Water=1)
+        >>> stream.get_atomic_flow('H') # kmol/hr of H
+        2.0
+        >>> stream.get_atomic_flow('O') # kmol/hr of O
+        1.0
         
         """
-        return (self.chemicals.formula_array[atomic_index[symbol], :] * self.mol).sum()
+        return (self.chemicals.formula_array[symbol_to_index[symbol], :] * self.mol).sum()
 
     def get_atomic_flows(self):
         """
         Return dictionary of atomic flow rates in kmol / hr.
         
+        >>> import thermosteam as tmo
+        >>> tmo.settings.set_thermo(['Water'], cache=True)
+        >>> stream = tmo.Stream(Water=1)
+        >>> stream.get_atomic_flows()
+        {'H': 2.0, 'O': 1.0}
+        
         """
         return array_to_atoms(self.chemicals.formula_array @ self.mol)
 
-    def get_flow(self, units, key= ...):
+    def get_flow(self, units, key=...):
         """
         Return an flow rates in requested units.
         
@@ -350,7 +377,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.get_flow('kg/hr', 'Water')
         20.0
@@ -360,7 +387,7 @@ class Stream:
         indexer = getattr(self, 'i' + name)
         return factor * indexer[key]
     
-    def set_flow(self, data, units, key= ...):
+    def set_flow(self, data, units, key=...):
         """
         Set flow rates in given units.
 
@@ -376,7 +403,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
         >>> s1 = tmo.Stream(ID='s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.set_flow(10, 'kg/hr', 'Water')
         >>> s1.get_flow('kg/hr', 'Water')
@@ -399,7 +426,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.get_total_flow('kg/hr')
         30.0
@@ -423,7 +450,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.set_total_flow(1.0,'kg/hr')
         >>> s1.get_total_flow('kg/hr')
@@ -447,7 +474,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.get_property('sigma', 'N/m') # Surface tension
         0.063780393
@@ -477,7 +504,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.set_property('P', 2, 'atm')
         >>> s1.P
@@ -748,7 +775,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> stream = Stream(Water=1, T=300)
         >>> other = Stream(Water=1, T=300)
         >>> stream.in_thermal_equilibrium(other)
@@ -765,7 +792,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s_sum = tmo.Stream.sum([s1, s1], 's_sum')
         >>> s_sum.show(flow='kg/hr')
@@ -788,10 +815,12 @@ class Stream:
         
         Examples
         --------
+        Mix two streams with the same thermodynamic property package:
+        
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
-        >>> s2 = s1.copy()
+        >>> s2 = s1.copy('s2')
         >>> s1.mix_from([s1, s2])
         >>> s1.show(flow='kg/hr')
         Stream: s1
@@ -799,6 +828,23 @@ class Stream:
          flow (kg/hr): Water    40
                        Ethanol  20
         
+        It's also possible to mix streams with different property packages
+        so long as all chemicals are defined in the mixed stream's property 
+        package:
+        
+        >>> tmo.settings.set_thermo(['Water'], cache=True) 
+        >>> s1 = tmo.Stream('s1', Water=40, units='kg/hr')
+        >>> tmo.settings.set_thermo(['Ethanol'], cache=True) 
+        >>> s2 = tmo.Stream('s2', Ethanol=20, units='kg/hr')
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
+        >>> s_mix = tmo.Stream('s_mix')
+        >>> s_mix.mix_from([s1, s2])
+        >>> s_mix.show(flow='kg/hr')
+        Stream: s_mix
+         phase: 'l', T: 298.15 K, P: 101325 Pa
+         flow (kg/hr): Water    40
+                       Ethanol  20
+        
         """
         others = [i for i in others if i]
         N_others = len(others)
@@ -830,7 +876,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
+        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'], cache=True)
         >>> tmo.settings.set_thermo(chemicals)
         >>> s = tmo.Stream('s', Water=20, Ethanol=10, units='kg/hr')
         >>> s1 = tmo.Stream('s1')
@@ -872,7 +918,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s2 = tmo.Stream('s2')
         >>> s2.link_with(s1)
@@ -906,7 +952,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s2 = tmo.Stream('s2')
         >>> s2.link_with(s1)
@@ -927,8 +973,10 @@ class Stream:
 
         Examples
         --------
+        Copy data from another stream with the same property package:
+        
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s2 = tmo.Stream('s2', Water=2, units='kg/hr')
         >>> s1.copy_like(s2)
@@ -936,6 +984,19 @@ class Stream:
         Stream: s1
          phase: 'l', T: 298.15 K, P: 101325 Pa
          flow (kg/hr): Water  2
+         
+        Copy data from another stream with a different property package:
+        
+        >>> import thermosteam as tmo
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
+        >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
+        >>> tmo.settings.set_thermo(['Water'], cache=True)
+        >>> s2 = tmo.Stream('s2', Water=2, units='kg/hr')
+        >>> s1.copy_like(s2)
+        >>> s1.show(flow='kg/hr')
+        Stream: s1
+         phase: 'l', T: 298.15 K, P: 101325 Pa
+         flow (kg/hr): Water  2
 
         """
         if isinstance(other, tmo.MultiStream): self.phases = other.phases
@@ -949,7 +1010,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
         >>> s1 = tmo.Stream('s1', Water=2, units='kg/hr')
         >>> s2 = tmo.Stream('s2', Water=1, units='kg/hr', T=300.00)
         >>> s1.copy_thermal_condition(s2)
@@ -980,7 +1041,7 @@ class Stream:
         Initialize streams:
         
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s2 = tmo.Stream('s2')
         
@@ -1045,7 +1106,7 @@ class Stream:
         Create a copy of a new stream:
         
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1_copy = s1.copy('s1_copy')
         >>> s1_copy.show(flow='kg/hr')
@@ -1078,7 +1139,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s2 = s1.flow_proxy()
         >>> s2.mol is s1.mol
@@ -1104,7 +1165,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s2 = s1.proxy()
         >>> s2.imol is s1.imol and s2.thermal_condition is s1.thermal_condition
@@ -1129,7 +1190,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.empty()
         >>> s1.F_mol
@@ -1180,7 +1241,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.get_bubble_point()
         BubblePoint([Water, Ethanol])
@@ -1202,7 +1263,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.get_dew_point()
         DewPoint([Water, Ethanol])
@@ -1224,7 +1285,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.bubble_point_at_T()
         BubblePointValues(T=350.00, P=76622, IDs=('Water', 'Ethanol'), z=[0.836 0.164], y=[0.486 0.514])
@@ -1246,7 +1307,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.bubble_point_at_P()
         BubblePointValues(T=357.09, P=101325, IDs=('Water', 'Ethanol'), z=[0.836 0.164], y=[0.49 0.51])
@@ -1270,7 +1331,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.dew_point_at_T()
         DewPointValues(T=350.00, P=48991, IDs=('Water', 'Ethanol'), z=[0.836 0.164], x=[0.984 0.016])
@@ -1294,7 +1355,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.dew_point_at_P()
         DewPointValues(T=368.66, P=101325, IDs=('Water', 'Ethanol'), z=[0.836 0.164], x=[0.984 0.016])
@@ -1316,7 +1377,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='kmol/hr')
         >>> s1.get_normalized_mol(('Water', 'Ethanol'))
         array([0.667, 0.333])
@@ -1339,7 +1400,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol'])
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol'], cache=True)
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='kg/hr')
         >>> s1.get_normalized_mass(('Water', 'Ethanol'))
         array([0.667, 0.333])
@@ -1362,7 +1423,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='m3/hr')
         >>> s1.get_normalized_vol(('Water', 'Ethanol'))
         array([0.667, 0.333])
@@ -1385,7 +1446,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='kmol/hr')
         >>> s1.get_molar_composition(('Water', 'Ethanol'))
         array([0.5 , 0.25])
@@ -1407,7 +1468,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='kg/hr')
         >>> s1.get_mass_composition(('Water', 'Ethanol'))
         array([0.5 , 0.25])
@@ -1429,7 +1490,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='m3/hr')
         >>> s1.get_volumetric_composition(('Water', 'Ethanol'))
         array([0.5 , 0.25])
@@ -1451,7 +1512,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol']) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='m3/hr')
         >>> s1.get_concentration(('Water', 'Ethanol'))
         array([27.671,  4.266])
@@ -1483,8 +1544,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol', 'Methanol', 'N2'])
-        >>> chemicals.N2.at_state(phase='g')
+        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol', 'Methanol', tmo.Chemical('N2', phase='g')], cache=True)
         >>> tmo.settings.set_thermo(chemicals) 
         >>> s1 = tmo.Stream('s1', N2=10, units='m3/hr', phase='g', T=330)
         >>> s2 = tmo.Stream('s2', Water=10, Ethanol=2, T=330)
@@ -1549,7 +1609,7 @@ class Stream:
     
     ### Representation ###
     
-    def diagram(self, file=None, format='png'):
+    def diagram(self, file=None, format='png'): # pragma: no cover
         from biosteam._digraph import make_digraph, save_digraph
         units = [i for i in (self.source, self.sink) if i]
         streams = sum([i.ins + i.outs for i in units], [])
@@ -1640,6 +1700,20 @@ class Stream:
     _ipython_display_ = show
     
     def print(self):
+        """
+        Print in a format that you can use recreate the stream.
+        
+        Examples
+        --------
+        >>> import thermosteam as tmo
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
+        >>> s1 = tmo.Stream(ID='s1',
+        ...                 Water=20, Ethanol=10, units='kg/hr',
+        ...                 T=298.15, P=101325, phase='l')
+        >>> s1.print()
+        Stream(ID='s1', phase='l', T=298.15, P=101325, Water=1.11, Ethanol=0.2171)
+        
+        """
         chemical_flows = utils.repr_IDs_data(self.chemicals.IDs, self.mol)
         price = utils.repr_kwarg('price', self.price)
         print(f"{type(self).__name__}(ID={repr(self.ID)}, phase={repr(self.phase)}, T={self.T:.2f}, "
