@@ -11,9 +11,10 @@ from ..units_of_measure import chemical_units_of_measure
 from .. import utils
 from inspect import signature
 
-__all__ = ("functor", "Functor",  "TFunctor", "TPFunctor", "TIntegralFunctor",
-           'display_asfunctor', 'functor_lookalike',
-           'functor_matching_params')
+__all__ = ("functor", "Functor",  "TFunctor", 
+           "TPFunctor", "TIntegralFunctor", 'display_asfunctor', 
+           'functor_lookalike', 'functor_matching_params', 
+           'parse_var', 'get_units', 'var_with_units')
 
 REGISTERED_ARGS = set()
 REGISTERED_FUNCTORS = []
@@ -21,19 +22,19 @@ REGISTERED_FUNCTORS = []
 # %% Utilities
 
 def functor_name(functor):
-    return functor.__name__ if hasattr(functor, "__name__") else type(functor).__name__
+    return functor.__name__ if hasattr(functor, "__name__") else type(functor).__name__    
 
 def display_asfunctor(functor, var=None, name=None, show_var=True):
     name = name or functor_name(functor)
     info = f"{name}{str(signature(functor)).replace('self, ', '')}"
+    units = functor.units if hasattr(functor, 'units') else None
     var = var or (functor.var if hasattr(functor, 'var') else None)
     if var:
         if show_var:
-            info += f" -> " + utils.var_with_units(var, chemical_units_of_measure)
+            info += " -> " + var_with_units(var, units)
         else:
-            name, *_ = var.split('.')
-            u = chemical_units_of_measure.get(name)
-            if u: info += f" -> {u}"
+            units = get_units(var, units)
+            if units: info += f" -> {units}"
     return info
 
 def functor_lookalike(cls):
@@ -52,12 +53,30 @@ def functor_arguments(params):
     base = functor_matching_params(params)
     return base, params[base._N_args:]
 
+def parse_var(var):
+    return var.split(".") if '.' in var else (var, "")
+
+def get_units(var, units=None):
+    name, phase = parse_var(var)
+    if isinstance(units, dict):
+        units = units.get(name)
+    if not units:
+        units = chemical_units_of_measure.get(name)
+    return units
+
+def var_with_units(var, units=None):
+    name, _ = parse_var(var)
+    units = get_units(name)
+    if units: var += f' [{units}]'
+    return var
+
 
 # %% Decorator
   
-def functor(f=None, var=None):
+def functor(f=None, var=None, units=None):
     """
-    Decorate a function of temperature, or both temperature and pressure as a Functor subclass.
+    Decorate a function of temperature, or both temperature and pressure 
+    to have an attribute, `functor`, that serves to create its functor counterpart.
     
     Parameters
     ----------
@@ -66,6 +85,14 @@ def functor(f=None, var=None):
         or both temperature and pressure.
     var : str, optional
         Name of variable returned (useful for bookkeeping).
+    units : dict, optional
+        Units of measure for functor signature.
+    
+    Returns
+    -------
+    f : function(T, *args) or function(T, P, *args)
+        Same function, but with an attribute `functor` that can create 
+        its `Functor` counterpart.
     
     Notes
     -----
@@ -82,15 +109,16 @@ def functor(f=None, var=None):
     >>> @functor(var='Psat')
     ... def Antoine(T, a, b, c):
     ...     return 10.0**(a - b / (T + c))
-    >>> f = Antoine(a=10.116, b=1687.5, c=-42.98)
-    >>> f
+    >>> Antoine(T=373.15, a=10.116, b=1687.5, c=-42.98) # functional
+    101157.148
+    >>> f = Antoine.functor(a=10.116, b=1687.5, c=-42.98) # as functor object
+    >>> f.show()
     Functor: Antoine(T, P=None) -> Psat [Pa]
      a: 10.116
      b: 1687.5
      c: -42.98
     >>> f(T=373.15)
-    101047.25357066597
-    
+    101157.148
     
     """
     if f:
@@ -99,18 +127,20 @@ def functor(f=None, var=None):
         dct = {'__slots__': (),
                'function': staticmethod(f),
                'params': params,
+               'units': units,
                'var': var}
-        cls = type(f.__name__, (base,), dct)
-        cls.__module__ = f.__module__
+        name = f.__name__
+        f.functor = type(name, (base,), dct)
     else:
-        return lambda f: functor(f, var)
-    return cls
+        return lambda f: functor(f, var, units)
+    return f
 
 
 # %% Functors
 
 class Functor:
     __slots__ = ('__dict__',)
+    hook = None
 
     def __init_subclass__(cls, args=None):
         if args:
@@ -168,7 +198,7 @@ class Functor:
         return f"<{self}>"
     
     def show(self):
-        info = f"Functor: {display_asfunctor(self)}"
+        info = f"Functor: {self}"
         data = self.__dict__
         for key, value in data.items():
             if callable(value):
@@ -181,7 +211,7 @@ class Functor:
                 info += f"\n {key}: {value}"
             else:
                 key, *_ = key.split('_')
-                u = chemical_units_of_measure.get(key)
+                u = get_units(key, self.units)
                 if u: info += ' ' + str(u)
         print(info)
         
@@ -192,19 +222,19 @@ class TFunctor(Functor, args=('T',)):
     __slots__ = ()
     kind = "functor of temperature (T; in K)"
     def __call__(self, T, P=None):
-        return self.function(T, **self.__dict__)
+        return self.hook(T, self.__dict__) if self.hook else self.function(T, **self.__dict__)
 
 class TPFunctor(Functor, args=('T', 'P')):
     __slots__ = ()
     kind = "functor of temperature (T; in K) and pressure (P; in Pa)"
     def __call__(self, T, P):
-        return self.function(T, P, **self.__dict__)
+        return self.hook(T, P, self.__dict__) if self.hook else self.function(T, P, **self.__dict__)
 
 class TIntegralFunctor(Functor, args=('Ta', 'Tb')):
     __slots__ = ()
     kind = "temperature integral functor (Ta to Tb; in K)"
     def __call__(self, Ta, Tb, P=None):
-        return self.function(Ta, Tb, **self.__dict__)
+        return self.hook(Ta, Tb, self.__dict__) if self.hook else self.function(Ta, Tb, **self.__dict__)
 
 
 
