@@ -49,7 +49,7 @@ class DewPoint:
     Examples
     --------
     >>> import thermosteam as tmo
-    >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
+    >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'], cache=True)
     >>> tmo.settings.set_thermo(chemicals)
     >>> DP = tmo.equilibrium.DewPoint(chemicals)
     >>> # Solve for dew point at constant temperautre
@@ -73,7 +73,7 @@ class DewPoint:
     def __init__(self, chemicals=(), thermo=None):
         thermo = settings.get_default_thermo(thermo)
         chemicals = tuple(chemicals)
-        key = (chemicals, thermo)
+        key = (chemicals, thermo.Gamma, thermo.Phi, thermo.PCF)
         cached = self._cached
         if key in cached:
             other = cached[key]
@@ -160,11 +160,11 @@ class DewPoint:
         --------
         >>> import thermosteam as tmo
         >>> import numpy as np
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
+        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'], cache=True)
         >>> tmo.settings.set_thermo(chemicals)
         >>> DP = tmo.equilibrium.DewPoint(chemicals)
         >>> DP.solve_Tx(z=np.array([0.5, 0.5]), P=101325)
-        (357.45184743327286, array([0.849, 0.151]))
+        (357.451847, array([0.849, 0.151]))
         """
         f = self._T_error
         z_norm = z/z.sum()
@@ -208,11 +208,11 @@ class DewPoint:
         --------
         >>> import thermosteam as tmo
         >>> import numpy as np
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
+        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'], cache=True)
         >>> tmo.settings.set_thermo(chemicals)
         >>> DP = tmo.equilibrium.DewPoint(chemicals)
         >>> DP.solve_Px(z=np.array([0.5, 0.5]), T=352.28)
-        (82444.29876052079, array([0.853, 0.147]))
+        (82444.29876, array([0.853, 0.147]))
  
        """
         z_norm = z/z.sum()
