@@ -9,6 +9,7 @@
 """
 import thermosteam as tmo
 import flexsolve as flx
+from chemicals import elements
 from . import _parse as prs
 from ..utils import chemicals_user
 from .._phase import NoPhase
@@ -101,7 +102,7 @@ class Reaction:
     --------
     >>> import thermosteam as tmo
     >>> import thermosteam.reaction as rxn
-    >>> chemicals = tmo.Chemicals(['H2O', 'H2', 'O2'])
+    >>> chemicals = tmo.Chemicals(['H2O', 'H2', 'O2'], cache=True)
     >>> tmo.settings.set_thermo(chemicals)
     >>> reaction = rxn.Reaction('2H2O -> 2H2 + O2', reactant='H2O', X=0.7)
     >>> reaction.show() # Note that the default basis is by 'mol'
@@ -320,7 +321,7 @@ class Reaction:
         
         >>> import thermosteam as tmo
         >>> import thermosteam.reaction as rxn
-        >>> chemicals = tmo.Chemicals(['H2', 'O2', 'H2O'])
+        >>> chemicals = tmo.Chemicals(['H2', 'O2', 'H2O'], cache=True)
         >>> tmo.settings.set_thermo(chemicals)
         >>> reaction = rxn.Reaction('2H2 + O2 -> 2H2O', reactant='H2', X=0.7)
         >>> s1 = tmo.Stream('s1', H2=10, O2=20, H2O=1000)
@@ -436,7 +437,7 @@ class Reaction:
         stoichiometry_by_mol = self._get_stoichiometry_by_mol()
         formula_array = self.chemicals.formula_array
         unbalanced_array = formula_array @ stoichiometry_by_mol
-        atoms = tmo.properties.elements.array_to_atoms(unbalanced_array)
+        atoms = elements.array_to_atoms(unbalanced_array)
         assert abs(sum(atoms.values())) < tol, (
             "atomic stoichiometry is unbalanced by the following molar stoichiometric coefficients:\n "
             + "\n ".join([f"{symbol}: {value}" for symbol, value in atoms.items()])
@@ -648,7 +649,7 @@ class ReactionSet:
         self._stoichiometry /= new_scale
     
     def __repr__(self):
-        return f"{type(self).__name__}([', '.join([repr(i) for i in self])])"
+        return f"{type(self).__name__}({[', '.join([repr(i) for i in self])]})"
     
     def show(self):
         info = f"{type(self).__name__} (by {self.basis}):"
@@ -708,7 +709,7 @@ class ParallelReaction(ReactionSet):
             
         >>> import thermosteam as tmo
         >>> import thermosteam.reaction as rxn
-        >>> chemicals = tmo.Chemicals(['H2', 'CH4', 'O2', 'CO2', 'H2O'])
+        >>> chemicals = tmo.Chemicals(['H2', 'CH4', 'O2', 'CO2', 'H2O'], cache=True)
         >>> tmo.settings.set_thermo(chemicals)
         >>> reaction = rxn.ParallelReaction([
         ...    #            Reaction definition          Reactant    Conversion
@@ -822,7 +823,7 @@ class SeriesReaction(ReactionSet):
         
         >>> import thermosteam as tmo
         >>> import thermosteam.reaction as rxn
-        >>> chemicals = tmo.Chemicals(['CH4', 'CO','O2', 'CO2', 'H2O'])
+        >>> chemicals = tmo.Chemicals(['CH4', 'CO','O2', 'CO2', 'H2O'], cache=True)
         >>> tmo.settings.set_thermo(chemicals)
         >>> reaction = rxn.SeriesReaction([
         ...     #            Reaction definition                 Reactant       Conversion
