@@ -234,8 +234,7 @@ chemical_units_of_measure = {'MW': AbsoluteUnitsOfMeasure('g/mol'),
                              'LHV': AbsoluteUnitsOfMeasure('J/mol'),
                              'S': AbsoluteUnitsOfMeasure('J/mol'), 
                              'G': AbsoluteUnitsOfMeasure('J/mol'), 
-                             'U': AbsoluteUnitsOfMeasure('J/mol'), 
-                             'A': AbsoluteUnitsOfMeasure('J/mol'),
+                             'U': AbsoluteUnitsOfMeasure('J/mol'),
                              'H_excess': AbsoluteUnitsOfMeasure('J/mol'), 
                              'S_excess': AbsoluteUnitsOfMeasure('J/mol'),
                              'dipole': AbsoluteUnitsOfMeasure('Debye'),
@@ -256,7 +255,6 @@ stream_units_of_measure = {'mol': AbsoluteUnitsOfMeasure('kmol/hr'),
                            'S': AbsoluteUnitsOfMeasure('kJ/hr'),
                            'G': AbsoluteUnitsOfMeasure('kJ/hr'),
                            'U': AbsoluteUnitsOfMeasure('kJ/hr'),
-                           'A': AbsoluteUnitsOfMeasure('kJ/hr'),
                            'C': AbsoluteUnitsOfMeasure('kJ/hr/K'),
 }
 for i in ('T', 'P', 'mu', 'V', 'rho', 'sigma',
@@ -297,7 +295,6 @@ definitions = {'MW': 'Molecular weight',
                'S': 'Entropy',
                'G': 'Gibbs free energy',
                'U': 'Internal energy',
-               'A': 'Helmholtz energy',
                'H_excess': 'Excess enthalpy',
                'S_excess': 'Excess entropy',
                'R': 'Universal gas constant',
